@@ -2,7 +2,7 @@ import __init__ as i
 i.upgrade()
 print(i.decimal(0.01,0.09,3))
 s = i.safe()
-s.encry('9D830K')
+s.encry('6C2F9D6A2E')
 s.decode('>,[*#!#$+===+:?')
 #i.author.phoneNumber()
 a = i.author()
